"use strict";
/**
 * @module nips/nip01
 * @description Implementation of NIP-01 functionality for direct messages
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEvent = createEvent;
exports.serializeEvent = serializeEvent;
exports.calculateEventHash = calculateEventHash;
exports.signedEvent = signedEvent;
exports.verifyEvent = verifyEvent;
exports.validateEvent = validateEvent;
const nostr_crypto_utils_1 = require("nostr-crypto-utils");
const errors_1 = require("../types/errors");
const sha256_1 = require("@noble/hashes/sha256");
const utils_1 = require("@noble/hashes/utils");
/**
 * Creates a new Nostr event with the specified parameters (NIP-01)
 * @param params - Event parameters
 * @returns Created event
 */
function createEvent(params) {
    const { kind, content, tags = [], created_at = Math.floor(Date.now() / 1000), pubkey = '' } = params;
    return {
        kind,
        content,
        tags,
        created_at,
        pubkey,
    };
}
/**
 * Serializes a Nostr event for signing/hashing (NIP-01)
 * @param event - Event to serialize
 * @returns Serialized event JSON string
 */
function serializeEvent(event) {
    return JSON.stringify([
        0,
        event.pubkey,
        event.created_at,
        event.kind,
        event.tags,
        event.content
    ]);
}
/**
 * Calculates the hash of a Nostr event (NIP-01)
 * @param event - Event to hash
 * @returns Event hash in hex format
 */
function calculateEventHash(event) {
    const serialized = serializeEvent(event);
    const hash = (0, sha256_1.sha256)(new TextEncoder().encode(serialized));
    return (0, utils_1.bytesToHex)(hash);
}
/**
 * Creates and signs a Nostr event (NIP-01)
 * @param params - Event parameters including private key
 * @returns Signed event
 */
async function signedEvent(params) {
    try {
        const { privateKey, ...eventParams } = params;
        // Get public key if not provided
        const pubkey = eventParams.pubkey || await (0, nostr_crypto_utils_1.getPublicKey)(privateKey);
        // Create the base event
        const event = createEvent({ ...eventParams, pubkey });
        // Calculate event hash/id
        const id = calculateEventHash(event);
        // Sign the event and get signature
        const signature = await (0, nostr_crypto_utils_1.signEvent)(event, privateKey);
        if (typeof signature !== 'string') {
            throw new Error('Invalid signature format');
        }
        // Return the signed event
        return {
            ...event,
            id,
            sig: signature
        };
    }
    catch (error) {
        throw new errors_1.NostrError('Failed to create signed event', errors_1.NostrErrorCode.EVENT_CREATION_FAILED);
    }
}
/**
 * Verifies a Nostr event's signature (NIP-01)
 * @param event - Event to verify
 * @returns True if signature is valid
 */
async function verifyEvent(event) {
    try {
        return await (0, nostr_crypto_utils_1.verifySignature)(event);
    }
    catch (error) {
        throw new errors_1.NostrError('Failed to verify event', errors_1.NostrErrorCode.EVENT_VERIFICATION_FAILED);
    }
}
/**
 * Validates a Nostr event structure (NIP-01)
 * @param event - Event to validate
 * @returns True if event structure is valid
 */
function validateEvent(event) {
    try {
        if (!event.pubkey || !event.created_at || event.kind === undefined || !event.content) {
            return false;
        }
        // Check timestamp is not in the future
        const now = Math.floor(Date.now() / 1000);
        if (event.created_at > now) {
            return false;
        }
        // Validate tags structure
        if (!Array.isArray(event.tags)) {
            return false;
        }
        for (const tag of event.tags) {
            if (!Array.isArray(tag)) {
                return false;
            }
        }
        return true;
    }
    catch {
        return false;
    }
}
//# sourceMappingURL=nip01.js.map