"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.encryptMessage = encryptMessage;
exports.decryptMessage = decryptMessage;
const nostr_crypto_utils_1 = require("nostr-crypto-utils");
const errors_1 = require("../types/errors");
/**
 * Encrypts a message following NIP-04 specification
 * @param message - The message to encrypt
 * @param privateKey - The sender's private key
 * @param publicKey - The recipient's public key
 * @returns Promise resolving to the encrypted message
 * @throws NostrError if encryption fails
 */
async function encryptMessage(message, privateKey, publicKey) {
    try {
        // Handle empty messages
        if (message === '') {
            message = ' ';
        }
        // Note: encryptNip04 expects (message, senderPrivkey, recipientPubkey)
        return await (0, nostr_crypto_utils_1.encryptMessage)(message, privateKey, publicKey);
    }
    catch (error) {
        throw new errors_1.NostrError('Message encryption failed: ' + error.message, errors_1.NostrErrorCode.ENCRYPTION_FAILED);
    }
}
/**
 * Decrypts a message following NIP-04 specification
 * @param encryptedMessage - The encrypted message to decrypt
 * @param privateKey - The recipient's private key
 * @param publicKey - The sender's public key
 * @returns Promise resolving to the decrypted message
 * @throws NostrError if decryption fails
 */
async function decryptMessage(encryptedMessage, privateKey, publicKey) {
    try {
        // Note: decryptNip04 expects (encryptedContent, recipientPrivkey, senderPubkey)
        const decrypted = await (0, nostr_crypto_utils_1.decryptMessage)(encryptedMessage, privateKey, publicKey);
        // Handle empty messages
        return decrypted === ' ' ? '' : decrypted;
    }
    catch (error) {
        throw new errors_1.NostrError('Message decryption failed: ' + error.message, errors_1.NostrErrorCode.DECRYPTION_FAILED);
    }
}
//# sourceMappingURL=nip04.js.map