"use strict";
/**
 * @module protocol/messages
 * @description Message handling for Nostr protocol
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageManager = void 0;
const nostr_crypto_utils_1 = require("nostr-crypto-utils");
const logger_1 = require("../utils/logger");
const nostr_1 = require("../types/nostr");
/**
 * Manages message encryption and verification for Nostr protocol
 * Provides utilities for secure message handling between users
 */
class MessageManager {
    /**
     * Encrypt a message for a recipient
     * @param content Message content to encrypt
     * @param recipientPubkey Recipient's public key
     * @param senderPrivateKey Sender's private key
     * @returns Encrypted message content
     * @throws {NostrError} If encryption fails
     */
    async encryptMessage(content, recipientPubkey, senderPrivateKey) {
        try {
            return await (0, nostr_crypto_utils_1.encryptMessage)(content, recipientPubkey, senderPrivateKey);
        }
        catch (error) {
            throw new nostr_1.NostrError('Failed to encrypt message', nostr_1.NostrErrorCode.ENCRYPTION_FAILED, { cause: error });
        }
    }
    /**
     * Verify a received message
     * @param senderPubkey Sender's public key
     * @returns True if message is verified
     * @throws {NostrError} If verification fails
     */
    async verifyMessage(senderPubkey) {
        try {
            // Implementation for message verification
            logger_1.logger.info('Message verified from:', senderPubkey);
            return true;
        }
        catch (error) {
            throw new nostr_1.NostrError('Failed to verify message', nostr_1.NostrErrorCode.VERIFICATION_FAILED, { cause: error });
        }
    }
}
exports.MessageManager = MessageManager;
//# sourceMappingURL=messages.js.map