"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyEvent = exports.createEvent = void 0;
const nostr_tools_1 = require("nostr-tools");
const types_1 = require("../../types");
const logger_1 = require("../../utils/logger");
/**
 * Create a signed Nostr event
 * @param content Event content
 * @param kind Event kind
 * @param privateKey Private key to sign the event
 * @param tags Optional event tags
 * @returns Signed Nostr event
 */
const createEvent = (content, kind, privateKey, tags = []) => {
    try {
        const pubkey = (0, nostr_tools_1.getPublicKey)(privateKey);
        const nonce = Math.random().toString(36).substring(2);
        const event = {
            content: `${content}:${nonce}`,
            kind,
            tags,
            created_at: Math.floor(Date.now() / 1000),
            pubkey,
            id: '',
            sig: ''
        };
        event.id = (0, nostr_tools_1.getEventHash)(event);
        event.sig = (0, nostr_tools_1.getSignature)(event, privateKey);
        return event;
    }
    catch (error) {
        logger_1.logger.error('Failed to create event', { error });
        throw new types_1.NostrError('Failed to create event', types_1.NostrErrorCode.EVENT_CREATION_ERROR, { cause: error });
    }
};
exports.createEvent = createEvent;
/**
 * Verify a Nostr event's signature and structure
 * @param event Event to verify
 * @returns True if event is valid, false otherwise
 */
const verifyEvent = (event) => {
    try {
        // Check basic event structure
        if (!(0, nostr_tools_1.validateEvent)(event)) {
            return false;
        }
        // Verify signature
        if (!(0, nostr_tools_1.verifySignature)(event)) {
            return false;
        }
        // Check timestamp is not in the future
        const now = Math.floor(Date.now() / 1000);
        if (event.created_at > now + 60) { // Allow 1 minute clock skew
            return false;
        }
        return true;
    }
    catch (error) {
        logger_1.logger.error('Failed to verify event', { error });
        return false;
    }
};
exports.verifyEvent = verifyEvent;
//# sourceMappingURL=nip01.js.map