"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidNpub = exports.formatPubkey = exports.validatePublicKey = exports.validatePrivateKey = void 0;
const nostr_tools_1 = require("nostr-tools");
const nostr_1 = require("../types/nostr");
const logger_1 = require("./logger");
/**
 * Validate a Nostr private key
 * @param key Private key to validate
 * @returns True if valid, false otherwise
 */
const validatePrivateKey = (key) => {
    try {
        // Check if it's a valid hex string of correct length (64 characters = 32 bytes)
        return /^[0-9a-f]{64}$/i.test(key);
    }
    catch (error) {
        logger_1.logger.error('Failed to validate private key', { error });
        return false;
    }
};
exports.validatePrivateKey = validatePrivateKey;
/**
 * Validate a Nostr public key
 * @param key Public key to validate
 * @returns True if valid, false otherwise
 */
const validatePublicKey = (key) => {
    try {
        // Check if it's a valid hex string of correct length (64 characters = 32 bytes)
        if (!/^[0-9a-f]{64}$/i.test(key)) {
            return false;
        }
        // Create a dummy event to validate the public key
        const dummyEvent = {
            kind: 1,
            created_at: Math.floor(Date.now() / 1000),
            tags: [],
            content: '',
            pubkey: key,
            id: '',
            sig: ''
        };
        return (0, nostr_tools_1.validateEvent)(dummyEvent);
    }
    catch (error) {
        logger_1.logger.error('Failed to validate public key', { error });
        return false;
    }
};
exports.validatePublicKey = validatePublicKey;
/**
 * Format a public key as an npub
 * @param pubkey Public key to format
 * @returns Formatted npub
 */
const formatPubkey = (pubkey) => {
    try {
        if (!(0, exports.validatePublicKey)(pubkey)) {
            throw new nostr_1.NostrError('Invalid public key', nostr_1.NostrErrorCode.INVALID_KEY);
        }
        return nostr_tools_1.nip19.npubEncode(pubkey);
    }
    catch (error) {
        logger_1.logger.error('Failed to format public key', { error });
        throw new nostr_1.NostrError('Failed to format public key', nostr_1.NostrErrorCode.FORMATTING_ERROR, { cause: error });
    }
};
exports.formatPubkey = formatPubkey;
/**
 * Check if a string is a valid npub
 * @param npub String to check
 * @returns True if valid npub, false otherwise
 */
const isValidNpub = (npub) => {
    try {
        if (!npub.startsWith('npub1')) {
            return false;
        }
        const decoded = nostr_tools_1.nip19.decode(npub);
        return decoded.type === 'npub' && (0, exports.validatePublicKey)(decoded.data);
    }
    catch (error) {
        logger_1.logger.error('Failed to validate npub', { error });
        return false;
    }
};
exports.isValidNpub = isValidNpub;
//# sourceMappingURL=key.utils.js.map